;+
;   
;    This program is free software: you can redistribute it and/or modify
;    it under the terms of the GNU Lesser General Public License as published
;    by the Free Software Foundation, either version 3 of the License, or
;    (at your option) any later version.
;
;    This program is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU Lesser General Public License for more details.
;
;    You should have received a copy of the GNU Lesser General Public License
;    along with this program.  If not, see <http://www.gnu.org/licenses/>.
;
;-

;+
; v.20131101a
;-

pro hw_alpha_save_header, fname, desc, ns, nl, nb, dt, bbl=bbl, wl=wl, bnames=bnames

  compile_opt idl2

  catch, theerror
  if theerror ne 0 then begin
    catch, /cancel
    print,!error_state.msg
    return
  endif
   
  ; open file, and attach extension .hdr
  openw,  lun, fname+'.hdr', /get_lun
  
  ; add scene specific OMEGA header info
  printf, lun, 'ENVI description = {'
  printf, lun, desc
  printf, lun, '}'
  printf, lun, 'samples = '  +strtrim(ns,2)
  printf, lun, 'lines = '    +strtrim(nl,2)
  printf, lun, 'bands = '    +strtrim(nb,2)
  printf, lun, 'data type = '+strtrim(dt,2)
  
  ; add standard OMEGA header info
  printf, lun, 'header offset = 0'
  printf, lun, 'file type = ENVI Standard'
  printf, lun, 'interleave = bil'
  printf, lun, 'sensor type = Unknown'
  printf, lun, 'byte order = 0'
  
  ; add band names, if set
  if keyword_set(bnames) then begin
    printf, lun, 'band names = {'
    if n_elements(bnames) eq 1 $
      then printf, lun, bnames $
      else printf, lun, [ bnames[0:nb-2]+',',bnames[nb-1] ]
    printf, lun, '}'
  endif
  
  ; add wavelength table, if set
  if keyword_set(wl) then begin
   printf, lun, 'wavelength units = Micrometers'
   printf, lun, 'wavelength = {'
   printf, lun, [strtrim(wl[0:nb-2],2)+',',strtrim(wl[nb-1],2)]
   printf, lun, '}'
  endif
  
  ; add bad band list, if set
  if keyword_set(bbl) then $
    printf, lun, format='("bbl = { ",351(i1,", "),i1," }")', bbl

  ; free lun and close file
  free_lun, lun

end
